#
# spec file for package polkit-gnome
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           polkit-gnome
Version:        0.105
Release:        15.6
Summary:        PolicyKit integration for the GNOME desktop
License:        LGPL-2.1-or-later
Group:          System/GUI/GNOME
URL:            http://www.freedesktop.org/wiki/Software/PolicyKit
Source0:        http://download.gnome.org/sources/polkit-gnome/%{version}/%{name}-%{version}.tar.bz2
Source1:        polkit-gnome-authentication-agent-1.desktop.in
# PATCH-FIX-UPSTREAM polkit-gnome-alternative-button-order-kde.patch bnc#538897 l.lunak@suse.cz
Patch3:         polkit-gnome-alternative-button-order-kde.patch
BuildRequires:  gobject-introspection-devel
BuildRequires:  gtk3-devel
BuildRequires:  intltool
BuildRequires:  polkit-devel >= 0.97
BuildRequires:  update-desktop-files
Supplements:    packageand(polkit:gnome-session)
Supplements:    packageand(polkit:lxsession)
Supplements:    packageand(polkit:xfce4-session)

%description
polkit-gnome provides an authentication agent for PolicyKit
that matches the look and feel of the GNOME desktop.

%lang_package

%prep
%autosetup -p1

%build
%configure \
  --disable-static
make %{?_smp_mflags}

%install
%make_install
mkdir -p %{buildroot}%{_sysconfdir}/xdg/autostart
sed -e "s,@LIBDIR@,%{_libexecdir},g" < %{SOURCE1} > %{buildroot}%{_sysconfdir}/xdg/autostart/polkit-gnome-authentication-agent-1.desktop
%suse_update_desktop_file polkit-gnome-authentication-agent-1
%find_lang polkit-gnome-1

%files
%license COPYING
%doc AUTHORS HACKING NEWS README
%{_sysconfdir}/xdg/autostart/*.desktop
%{_libexecdir}/polkit-gnome-authentication-agent-1

%files lang -f polkit-gnome-1.lang

%changelog
* Tue Nov 28 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup instead of %%setup/%%patch.
* Sat Dec  4 2021 Callum Farmer <gmbr3@opensuse.org>
- Add NotShowIn for Budgie desktop, it has budgie-polkit
* Sun Nov 28 2021 Alexei Podvalsky <avvissu@yandex.by>
- Disable agent startup on Pantheon desktop
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Thu Oct 27 2011 dimstar@opensuse.org
- Update to version 0.105:
  + Various build fixes
  + Updated translations.
* Mon Oct 17 2011 dimstar@opensuse.org
- Update to version 0.104:
  + Updated translations.
* Tue Sep 20 2011 vuntz@opensuse.org
- Update to version 0.103:
  + Drop polkit-gtk library.
  + Drop support for GTK+ 2.
  + Build fixes.
- Drop libpolkit-gtk-1-0 and libpolkit-gtk-1-devel subpackages,
  since the library got removed. Note that nothing is using this
  library in Factory.
- Stop passing --with-gtk=3.0 to configure: this option is now
  gone.
- Stop passing --libexecdir=%%{_libexecdir}/polkit-gnome to
  configure: we're happy with the standard libexecdir.
- Remove gtk-doc BuildRequires and stop passing --enable-gtk-doc to
  configure: such documentation only existed with the library.
- Re-enable parallel build.
- Update polkit-gnome-authentication-agent-1.desktop.in: do not add
  polkit-gnome in the Exec path, since we changed the libexecdir.
* Wed Aug 17 2011 dimstar@opensuse.org
- Update to version 0.102:
  + Use GtkBox instead of GtkHBox
  + Updated translations.
* Thu Apr 14 2011 fcrozat@novell.com
- Fix path for polkit agent on x86_64 in by replacing @LIBDIR@ in
  polkit-gnome-authentication-agent-1.desktop.in.
* Mon Mar  7 2011 fcrozat@novell.com
- Update to version 0.101:
  + Return error when authentication dialog is dismissed
  + Fix crashers if icons cannot be loaded
  + Don't use deprecated polkit API
  + Fix warnings with gcc 4.6
  + Connect to the session bus
- Changes from version 0.100:
  + Make --with-gtk work with introspection
  + Nuke desktop file for autostart
  + Don't use a status icon for temporary authorizations
  + Use avatar-default instead of stock_person
  + Don't use gtk_dialog_set_has_separator
  + Don't use gtk_widget_hide_all
  + Add a --with-gtk configure option
- Drop polkit-gnome-OnlyShowIn.patch: this is obsolete now.
- Add as a source a .desktop file to start polkit agent: it was
  removed from tarball, but we still need it.
- Use gtk3-devel BuildRequires instead of gtk2-devel, and pass
  - -with-gtk=3.0 to configure to build with gtk3.
* Wed Dec  1 2010 gber@opensuse.org
- added supplements for xfce4-session and lxsession so polkit-gnome
  gets installed by default for LXDE/XFCE
* Thu Sep 16 2010 vuntz@opensuse.org
- Update to version 0.99:
  + Fix up --string-prefix usage to work with latest
    gobject-introspection
* Tue Aug 31 2010 aj@suse.de
- Recommend instead of require lang package since it's not mandatory.
* Thu Aug 26 2010 vuntz@opensuse.org
- Update to version 0.97:
  + Compile with -DGSEAL_ENABLE (bgo#616386)
  + Remove lock down functionality
  + Port from dbus-glib to gdbus
  + Avoid deprecated polkit_authority_get() function
  + Hide the agent autostart desktop file
  + Use standard icon names
- Changes from version 0.96:
  + Fix bug with authenticating multiple possible users
  + Updated translations.
- Changes from version 0.95:
  + Set status icon invisible before unref'ing it
  + Add test-case for fdo#23867
  + Add support for locking down actions
  + Add GObject Introspection for libpolkit-gtk-1
  + In the example, print backend details on stdout
  + Support multiple outstanding authentication requests
  + Use new API in polkit 0.95 for lock down
  + Updated translations.
- Rebase polkit-gnome-OnlyShowIn.patch.
- Rebase polkit-gnome-alternative-button-order-kde.patch.
- Drop polkit-gnome-fix-hide-status-icon-kde.patch: fixed upstream.
- Add gobject-introspection-devel BuildRequires to have
  introspection support.
- Change polkit-devel BuildRequires to >= 0.97.
- Disable parallel build for now since it fails.
* Mon May 24 2010 vuntz@opensuse.org
- Change Supplements to be on polkit and gnome-session instead of
  just gnome-session: polkit-gnome is useless if polkit is not
  installed.
* Thu May 20 2010 llunak@novell.com
- do not use the authentication agent in KDE (bnc#576248)
* Thu Oct  1 2009 vuntz@opensuse.org
- Rename patches to comply with patch naming policy.
* Mon Sep 28 2009 llunak@novell.com
- use the authentication agent also in KDE (bnc#538897)
- use the proper button order in KDE
- fix status icon not hiding
* Thu Aug 13 2009 kay.sievers@novell.com
- Update to version 0.94:
  - Add library with a PolkitLockButton widget
  - Make use of new API to better cope with one-shot authorizations
- Create libpolkit-gtk-1-0 package, and devel package.
* Wed Aug  5 2009 vuntz@novell.com
- Add Supplements on gnome-session, since we want this installed by
  default for GNOME.
* Tue Jul 21 2009 kay.sievers@novell.com
- update to version 0.93
* Mon Jul 20 2009 vuntz@novell.com
- Clean up spec file.
* Sun Jul 19 2009 kay.sievers@novell.com
- initial import of polkit-gnome 0.92
